@@ -7,7 +7,7 @@ use Types::Standard qw(Bool Int Object Str);
 
 use WebService::Mattermost::V4::API;
 
-our $VERSION = 0.23;
+our $VERSION = 0.24;
 
 ################################################################################
 
@@ -15,7 +15,7 @@ has [ qw(base_url username password) ] => (is => 'ro', isa => Str, required => 1
 
 has api_version                => (is => 'ro', isa => Int,  default => 4);
 has [ qw(authenticate debug) ] => (is => 'rw', isa => Bool, default => 0);
-has [ qw(auth_token user_id) ] => (is => 'rw', isa => Str,  default => '');
+has [ qw(auth_token user_id) ] => (is => 'rw', isa => Str,  default => q{});
 
 has api => (is => 'ro', isa => Object, lazy => 1, builder => 1, clearer => 1);
 
@@ -104,14 +104,14 @@ WebService::Mattermost - Perl client library for Mattermost's REST API and webso
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 DESCRIPTION
 
 WebService::Mattermost provides websocket and REST API integrations for Mattermost,
 and supercedes C<Net::Mattermost::Bot>, replacing all functionality.
 
-See the L<repository|(https://github.com/n7st/webservice-mattermost> for more
+See the L<repository|https://github.com/n7st/webservice-mattermost> for more
 information.
 
 =head2 SYNOPSIS
