@@ -10,7 +10,7 @@ sub error_return {
     my $self  = shift;
     my $error = shift;
 
-    $error = sprintf('%s. No API query was made.', $error);
+    $error = sprintf '%s. No API query was made.', $error;
 
     return { error => 1, message => $error };
 }
@@ -31,7 +31,7 @@ WebService::Mattermost::Role::Returns - Standard returns for user-facing subrout
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 DESCRIPTION
 
