@@ -18,14 +18,14 @@ sub mmauthtoken {
     my $self  = shift;
     my $token = shift;
 
-    return sprintf('MMAUTHTOKEN=%s', $token);
+    return sprintf 'MMAUTHTOKEN=%s', $token;
 }
 
 sub bearer {
     my $self  = shift;
     my $token = shift;
 
-    return sprintf('Bearer %s', $token);
+    return sprintf 'Bearer %s', $token;
 }
 
 ################################################################################
@@ -50,7 +50,7 @@ WebService::Mattermost::Role::UserAgent - Internal user agent role.
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 DESCRIPTION
 
